CreateSessionWithPassword class final

Input passed to a password request body mapper.

Constructors

CreateSessionWithPassword({required String username, required String password})
Creates password credentials.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
password → String
Password supplied by the caller.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → String
Login identifier supplied by the caller.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited