RepositorySessionCookies class final

A session whose credentials are maintained by a cookie jar.

Inheritance

Constructors

RepositorySessionCookies({String? identity})
Creates a cookie-backed session marker.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
identity → String?
Stable identity associated with the cookie session, when known.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject → String?
Stable identity used to isolate cached repository data.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited