RepositorySessionRefresh<Session extends RepositorySession> class final

Configuration for a session refresh endpoint.

Constructors

RepositorySessionRefresh.post({required RepositoryUrl endpoint, required RepositoryAuthenticationBody<RefreshSession<Session>> body, required RepositoryRefreshDecoder<Session> decode})
Creates a POST refresh operation.
const
RepositorySessionRefresh.put({required RepositoryUrl endpoint, required RepositoryAuthenticationBody<RefreshSession<Session>> body, required RepositoryRefreshDecoder<Session> decode})
Creates a PUT refresh operation.
const

Properties

body → RepositoryAuthenticationBody<RefreshSession<Session>>
Maps the current session into the refresh request body.
final
decode → RepositoryRefreshDecoder<Session>
Maps the response and previous value into one complete replacement.
final
endpoint → RepositoryUrl
Endpoint called to renew the session.
final
hashCode → int
The hash code for this object.
no setterinherited
method → RepositoryHttpMethod
HTTP method called to renew the session.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited