RepositorySessionStateAuthenticated class final

A usable authenticated session is available.

Inheritance

Constructors

RepositorySessionStateAuthenticated(RepositorySession session)
Creates an authenticated state.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session → RepositorySession
Current session.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited