RepositorySessionStorage class abstract interface

Persistence dedicated to authentication credentials.

Implementations should use secure platform storage in production.

Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete() → Future<void>
Removes the serialized session.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → Future<String?>
Reads the serialized session, or null when none exists.
toString() → String
A string representation of this object.
inherited
write(String value) → Future<void>
Atomically replaces the serialized session.

Operators

operator ==(Object other) → bool
The equality operator.
inherited